@@ -20,7 +20,7 @@ XML::TinyXML::Node - Tinyxml Node object
   $parent_node->addChildNode($child_node);
 
   # or if we want to create a childnode in a single statemnet
-  $child_node = XML::TinyXML::Node->new("child", "somevalue", $attrs, $parent_node);
+  $child_node = XML::TinyXML::Node->new("child", "somevalue", $parent_node);
 
   # we can later retrive the "child" node by calling
   $child_node = $xml->getNode("/nodelabel/child");
@@ -58,7 +58,7 @@ Reference to the underlying XmlNodePtr object (which is a binding to the XmlNode
 package XML::TinyXML::Node;
 
 use strict;
-our $VERSION = '0.16';
+our $VERSION = $XML::TinyXML::Version;
 
 =item * new ($entity, $value, $parent, %attrs)
 
@@ -82,7 +82,7 @@ Returns a valid XML::TinyXML::Node object
 
 =cut
 sub new {
-    my ($class, $entity, $value, $attrs, $parent) = @_;
+    my ($class, $entity, $value, $parent, %attrs) = @_;
     return undef unless($entity);
     my $node = undef;
     if(ref($entity) && UNIVERSAL::isa($entity, "XmlNodePtr")) {
@@ -100,56 +100,36 @@ sub new {
         }
         if($pnode) {
             XML::TinyXML::XmlAddChildNode($pnode, $node);
-        } 
+        } else {
+        }
     } 
     my $self = {};
     bless($self, $class);
     $self->{_node} = $node;
-    if($attrs && ref($attrs) eq "HASH") {
-        $self->addAttributes(%$attrs);
+    if(%attrs) {
+        $self->AddAttributes(%attrs);
     }
     $self;
 }
 
-=item * cleanAttributes ()
-
-Removes all node attributes
+=item * cleanAttributes
 
 =cut
 sub cleanAttributes {
-    my ($self) = @_;
-    return XML::TinyXML::XmlClearAttributes($self->{_node});
 }
 
-=item * removeAttribute ($index)
-
-Removes attribute at $index
-
-=cut
 sub removeAttribute {
     my ($self, $index) = @_;
     return XML::TinyXML::XmlRemoveAttribute($self->{_node}, $index);
 }
 
-#=item * removeAttributeByName ($name)
-#=cut
-
-=item * loadHash ($hashref, [ $childname ])
-
-Loads an hashref and represent it as an xml subbranch.
-
-$hashref 
-
-if $childname is specified, newly created childnodes will use it as their name
+=item * loadHash ($hash, [ $nest ])
 
 =cut
 sub loadHash {
-    my ($self, $hash, $childname, $reset) = @_;
-
-    $self->removeAllChildren if $reset;
-
+    my ($self, $hash, $nest) = @_;
     foreach my $k (keys(%$hash)) {
-        my $name = $childname || $k;
+        my $name = $nest || $k;
         if(!ref($hash->{$k}) || ref($hash->{$k}) eq "SCALAR") {
             $self->addChildNode(XML::TinyXML::Node->new($name, $hash->{$k}));
         } elsif(ref($hash->{$k}) eq "HASH") {
@@ -159,7 +139,7 @@ sub loadHash {
         } elsif(ref($hash->{$k}) eq "ARRAY") {
             foreach my $entry (@{$hash->{$k}}) {
                 #warn "Anonymous/Nested arrayrefs are flattened !!! This should be fixed in the future";
-                #$self->parent->addChildNode($childname);
+                #$self->parent->addChildNode($nest);
                 $self->loadHash({ __import__ => $entry }, $name);
             }
         }
@@ -168,11 +148,6 @@ sub loadHash {
 
 =item * toHash ([ $parent ])
 
-Export the xml structure into an hashref (formerly the inverse of loadHash)
-
-if $parent is specified the resulting structure will be connected to $parent.
-(NOTE: $parent MUST obviously be an hashref)
-
 =cut
 sub toHash {
     my ($self, $parent) = @_;
@@ -209,11 +184,6 @@ sub toHash {
 
 =item * updateAttributes (%attrs)
 
-Updates all attributes.
-
-This method simply clean all current attributes and replace them with 
-the ones specified in the %attrs hash
-
 =cut
 sub updateAttributes {
     my ($self, %attrs) = @_;
@@ -223,22 +193,16 @@ sub updateAttributes {
 
 =item * addAttributes (%attrs)
 
-Add attributes.
-
 =cut
 sub addAttributes {
     my ($self, %attrs) = @_;
-    foreach my $key (sort keys %attrs) {
+    foreach my $key (keys %attrs) {
         XML::TinyXML::XmlAddAttribute($self->{_node}, $key, $attrs{$key});
     }
 }
 
 =item * name ([$newname])
 
-Set/Get the name of a node.
-if $newname is specified it will be used as the new name, 
-otherwise the current name is returned
-
 =cut
 sub name { 
     my ($self, $newname) = @_;
@@ -249,10 +213,6 @@ sub name {
 
 =item * value ([$newval])
 
-Set/Get the vlue of a node.
-if $newval is specified it will be used as the new value, 
-otherwise the current value is returned
-
 =cut
 sub value {
     my ($self, $newval) = @_;
@@ -261,40 +221,9 @@ sub value {
     return $self->{_node}->value;
 }
 
-=item * vpath ()
-
-Get the absolute path of a node.
-
-=cut
-sub path {
-    my $self = shift;
-    return $self->{_node}->path;
-}
-
-=item * getAttribute ($index)
-
-=cut
-sub getAttribute {
-    my ($self, $index) = @_;
-    my $attr = XML::TinyXML::XmlGetAttribute($self->{_node}, $index);
-    return XML::TinyXML::NodeAttribute->new($attr) if ($attr);
-}
-
-=item * getAttributes ()
-
-=cut
-sub getAttributes {
-    my ($self) = shift;
-    my @res;
-    for(my $i = 1; $i <= XML::TinyXML::XmlCountAttributes($self->{_node}); $i++) {
-        push @res, XML::TinyXML::NodeAttribute->new(XML::TinyXML::XmlGetAttribute($self->{_node}, $i));
-    }
-    return wantarray?@res:\@res;
-}
-
 =item * attributes ()
 
-Read-Only method to obtain an hashref of the attributes in this node
+Read-Only method to obtain an hashref to the attributes of this node
 
 =cut
 sub attributes {
@@ -308,10 +237,6 @@ sub attributes {
 }
 
 =item * getChildNode ($index)
-
-Returns child node at $index.
-The returned node will be a Xml::TinyXML::Node object
-
 =cut
 sub getChildNode {
     my ($self, $index) = @_;
@@ -319,10 +244,6 @@ sub getChildNode {
 }
 
 =item * getChildNodeByName ($name)
-
-Returns the first child node whose name matches $name.
-The returned node will be a Xml::TinyXML::Node object
-
 =cut
 sub getChildNodeByName {
     my ($self, $name) = @_;
@@ -330,19 +251,7 @@ sub getChildNodeByName {
     return XML::TinyXML::Node->new(XML::TinyXML::XmlGetChildNodeByName($self->{_node}, $name));
 }
 
-=item * getChildrenByName ($name)
-
-Alias for getChildNodeByName
-
-=cut
-sub getChildrenByName {
-    return getChildNodeByName(@_);
-}
-
 =item * countChildren ()
-
-Returns the actual number of children
-
 =cut
 sub countChildren {
     my $self = shift;
@@ -350,25 +259,18 @@ sub countChildren {
 }
 
 =item * children ()
-
-Returns an array containing all actual children in the form of Xml::TinyXML::Node objects
-
 =cut
 sub children {
     my ($self) = @_;
-    my @children;
-    for (my $i = 1; $i <= XML::TinyXML::XmlCountChildren($self->{_node}); $i++) {
-        push (@children, XML::TinyXML::Node->new(XML::TinyXML::XmlGetChildNode($self->{_node}, $i)));
+    my @children = ();
+    for(my $i = 1; $i <= XML::TinyXML::XmlCountChildren($self->{_node}); $i++) {
+        push(@children, XML::TinyXML::Node->new(XML::TinyXML::XmlGetChildNode($self->{_node}, $i)));
     }
-    return wantarray?@children:\@children;
+    return @children;
 }
 
 =item * addChildNode ($child)
 
-Adds a new child node.
-
-$child MUST be a XML::TinyXML::Node object
-
 =cut
 sub addChildNode {
     my ($self, $child) = @_;
@@ -376,31 +278,7 @@ sub addChildNode {
     return XML::TinyXML::XmlAddChildNode($self->{_node}, $child->{_node});
 }
 
-=item * removeChildNode ($index)
-
-Removes child node at provided $index.
-
-=cut
-sub removeChildNode {
-    my ($self, $index) = @_;
-    XML::TinyXML::XmlRemoveChildNode($self->{_node}, $index);
-}
-
-=item * removeAllChildren
-
-Removes all children from this node
-
-=cut
-sub removeAllChildren {
-    my ($self) = @_;
-    for (my $i = 1; $i <= $self->countChildren; $i++) {
-        XML::TinyXML::XmlRemoveChildNode($self->{_node}, $i);
-    }
-}
-
-=item * parent ()
-
-Read-Only method which returns the parent node in the form of a XML::TinyXML::Node object.
+=item * parent ($child)
 
 =cut
 sub parent {
@@ -408,36 +286,12 @@ sub parent {
     return XML::TinyXML::Node->new($self->{_node}->parent);
 }
 
-=item * nextSibling ()
-
-Returns the next sibling of this node (if any),
-undef otherwise.
-
-=cut
-sub nextSibling {
-    my ($self) = @_;
-    return XML::TinyXML::Node->new(XML::TinyXML::XmlNextSibling($self->{_node}));
-}
-
-=item * prevSibling ()
-
-Returns the previous sibling of this node (if any),
-undef otherwise.
-
-=cut
-sub prevSibling {
-    my ($self) = @_;
-    return XML::TinyXML::Node->new(XML::TinyXML::XmlPrevSibling($self->{_node}));
-}
-
 =item * type ()
-
 Returns the "type" of a XML::TinyXML::Node object.
 type can be :
     NODE
     COMMENT
     CDATA
-
 =cut
 sub type {
     my ($self) = @_;
